==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/acl/lang/es/lang.php <==
<?php
/**
 * Spanish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Miguel Pagano <miguel.pagano@gmail.com>
 * @author Oscar M. Lage <r0sk10@gmail.com>
 * @author Gabriel Castillo <gch@pumas.ii.unam.mx>
 * @author oliver@samera.com.py
 */
$lang['admin_acl']             = 'Administración de lista de control de acceso';
$lang['acl_group']             = 'Grupo';
$lang['acl_user']              = 'Usuario';
$lang['acl_perms']             = 'Permiso para';
$lang['page']                  = 'Página';
$lang['namespace']             = 'Espacio de nombres';
$lang['p_user_id']             = 'El usuario <b class="acluser">%s</b> tiene los siguientes permisos sobre la página <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'El usuario <b class="acluser">%s</b> tiene los siguientes permisos sobre el espacio de nombres <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Los miembros del grupo <b class="aclgroup">%s</b> tiene los siguientes permisos sobre la página <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Los miembros del grupo <b class="aclgroup">%s</b> tiene los siguientes permisos sobre el espacio de nombres <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Por favor <b>proporciones un usuario o grupo</b>en el formulario arriba mostrado para ver o editar los permisos asignados sobre la página<b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Por favor <b>proporciones un usuario o grupo</b>en el formulario arriba mostrado para ver o editar los permisos asignados sobre el espacio de nombres <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Nota: Esos permisos no fueron establecidos explicitamente sino que fueron heredados desde otros grupos o espacios de nombres superiores';
$lang['p_isadmin']             = 'Nota: El grupo o usuario seleccionado simepres tiene permisos totales debido a que se encuentra configurado como superusuario';
$lang['current']               = 'Reglas ACL vigentes';
$lang['where']                 = 'Pagina/Espacio de nombres';
$lang['who']                   = 'Usuario/Grupo';
$lang['perm']                  = 'Permisos';
$lang['acl_perm0']             = 'ninguno';
$lang['acl_perm1']             = 'Leer';
$lang['acl_perm2']             = 'Editar';
$lang['acl_perm4']             = 'Crear';
$lang['acl_perm8']             = 'Subir un fichero';
$lang['acl_perm16']            = 'Borrar';
$lang['acl_new']               = 'Agregar una nueva entrada';
$lang['acl_mod']               = 'Modificar una entrada';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/acl/lang/es/lang.php <==
<?php
/**
 * Spanish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Miguel Pagano <miguel.pagano@gmail.com>
 * @author Oscar M. Lage <r0sk10@gmail.com>
 * @author Gabriel Castillo <gch@pumas.ii.unam.mx>
 * @author oliver@samera.com.py
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Manuel Meco <manuel.meco@gmail.com>
 * @author VictorCastelan <victorcastelan@gmail.com>
 * @author Jordan Mero  hack.jord@gmail.com
 */
$lang['admin_acl']             = 'Administración de lista de control de acceso';
$lang['acl_group']             = 'Grupo';
$lang['acl_user']              = 'Usuario';
$lang['acl_perms']             = 'Permiso para';
$lang['page']                  = 'Página';
$lang['namespace']             = 'Espacio de nombres';
$lang['btn_select']            = 'Seleccionar';
$lang['p_user_id']             = 'El usuario <b class="acluser">%s</b> tiene los siguientes permisos sobre la página <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'El usuario <b class="acluser">%s</b> tiene los siguientes permisos sobre el espacio de nombres <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Los miembros del grupo <b class="aclgroup">%s</b> tiene los siguientes permisos sobre la página <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Los miembros del grupo <b class="aclgroup">%s</b> tiene los siguientes permisos sobre el espacio de nombres <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Por favor <b>proporciones un usuario o grupo</b>en el formulario arriba mostrado para ver o editar los permisos asignados sobre la página<b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Por favor <b>proporciones un usuario o grupo</b>en el formulario arriba mostrado para ver o editar los permisos asignados sobre el espacio de nombres <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Nota: Esos permisos no fueron establecidos explicitamente sino que fueron heredados desde otros grupos o espacios de nombres superiores';
$lang['p_isadmin']             = 'Nota: El grupo o usuario seleccionado simepres tiene permisos totales debido a que se encuentra configurado como superusuario';
$lang['p_include']             = 'Los Permisos superiores incluyen inferiores. Crear, cargar y eliminar los permisos sólo se aplican a los nombres, no a las páginas.';
$lang['current']               = 'Reglas ACL vigentes';
$lang['where']                 = 'Pagina/Espacio de nombres';
$lang['who']                   = 'Usuario/Grupo';
$lang['perm']                  = 'Permisos';
$lang['acl_perm0']             = 'ninguno';
$lang['acl_perm1']             = 'Leer';
$lang['acl_perm2']             = 'Editar';
$lang['acl_perm4']             = 'Crear';
$lang['acl_perm8']             = 'Subir un fichero';
$lang['acl_perm16']            = 'Borrar';
$lang['acl_new']               = 'Agregar una nueva entrada';
$lang['acl_mod']               = 'Modificar una entrada';
